#
# spec file for package lcov
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           lcov
Version:        1.16+git.20220603.dfeb750
Release:        bp155.1.9
Summary:        A Graphical GCOV Front-end
License:        GPL-2.0-or-later
Group:          Development/Tools/Other
URL:            https://github.com/linux-test-project/lcov
Source0:        %{name}-%{version}.tar.xz
Requires:       findutils
Requires:       gcc
Requires:       perl-GD
Requires:       perl-PerlIO-gzip
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
LCOV is a graphical front-end for GCC's coverage testing tool gcov. It collects
gcov data for multiple source files and creates HTML pages containing the
source code annotated with coverage information. It also adds overview pages
for easy navigation within the file structure.

%prep
%setup -q
sed -i "s/1.0/%{version}/" bin/get_version.sh

%build

%install
make install PREFIX=%{buildroot}/usr CFG_DIR=%{buildroot}/etc

%files
%defattr(644,root,root)
%config %{_sysconfdir}/lcovrc
%{_mandir}/man1/lcov.1.gz
%{_mandir}/man1/genhtml.1.gz
%{_mandir}/man1/geninfo.1.gz
%{_mandir}/man1/genpng.1.gz
%{_mandir}/man1/gendesc.1.gz
%{_mandir}/man5/lcovrc.5.gz
%defattr(-,root,root)
%{_bindir}/lcov
%{_bindir}/genhtml
%{_bindir}/geninfo
%{_bindir}/genpng
%{_bindir}/gendesc

%changelog
* Wed Jun 15 2022 mliska@suse.cz
- Update to version 1.16+git.20220603.dfeb750:
  * lcov: Finalize release 1.16
  * Makefile: Create make target for creating release tags
  * lcov: Update website links
  * geninfo: Fix handling of source path containing non-ASCII characters
  * geninfo: support remove CR endings of old intermediate text
  * lcov: Add file attributes for shell scripts
  * genhtml: Add option to change HTML footer text
  * genhtml: Add option to change HTML header text
  * genpng: Improve dark-mode support
  * lcov: quote tool_dir to enable paths with spaces.
  * lcov: Improve JSON module selection
  * lcov: Make JSON module configurable
  * Fix genhtml on macOS
  * genhtml/genpng/lcov:  add missing rc support and man page entries
  * Add a dark mode option
  * example: Fix example relying on undefined behavior
  * lcov: add a new --fail-under-lines option
  * lcov: Finalize release 1.15
  * Makefile: Reduce unnecessary meta-data in tar and RPM files
  * geninfo: Add workaround for MSYS GCC problem
  * geninfo: Change json module
  * geninfo: Fix warning due to non-numerical branch count
  * geninfo: Fix missing check for unterminated exclusion marker
  * Exclusion of exception branches
  * genhtml: Fix applying prefix to a prefix filename
  * genhtml: Add more demangler options
  * tests: Minor improvements
* Thu Jan 13 2022 Federico Mena Quintero <federico@suse.com>
- Add dependency on findutils, as lcov's scripts use find(1) to locate
  various files in the user's build directories.  bsc#1194671
* Fri Oct 23 2020 Martin Liška <mliska@suse.cz>
- Fix output of --version option.
* Wed Aug 12 2020 mliska@suse.cz
- Update to version 1.15+git.20200812.d100e6c:
  * lcov: Finalize release 1.15
  * Makefile: Reduce unnecessary meta-data in tar and RPM files
  * geninfo: Add workaround for MSYS GCC problem
  * geninfo: Change json module
  * geninfo: Fix warning due to non-numerical branch count
  * geninfo: Fix missing check for unterminated exclusion marker
  * Exclusion of exception branches
  * genhtml: Fix applying prefix to a prefix filename
  * genhtml: Add more demangler options
  * tests: Minor improvements
  * tests: Minor test improvements
  * man: Add clarification regarding file patterns
  * geninfo: Change gzip decompression module
  * Fixed processing GCOV intermediate format.
* Mon Jul 27 2020 Miklos Vajna <vmiklos@collabora.com>
- Remove no longer needed kernel-coverage conflict (bsc#1078447)
* Sun Jul 26 2020 Bernhard Wiedemann <bwiedemann@suse.com>
- Update to version 1.15+git.20200723.b668fab:
  * tests: Fix subdirectory testing
  * tests: Provide option to specify tool parameters
  * tests: Simplify test Makefiles
  * Allow to override man page date (boo#1047218)
  * bin: remove outdated FSF mailing address from license boilerplate
* Mon Jun  3 2019 mliska@suse.cz
- Update to version 1.15+git.20190524.75fbae1 (boo#1138276):
  * geninfo: Add intermediate JSON format support
  * geninfo: Add intermediate text format support
  * genhtml: Maintain order of branches in unnamed blocks
  * man: Fix missing parameter in genhtml synopsis
  * lcov: Finalize release 1.14
  * geninfo: Fix missing FN: entries in result files
  * Makefile: Make Perl path install-time configurable
  * bin,test: Use /usr/bin/env to locate script interpreters
  * bin/*: Remove '-w' from interpreter specifications
  * geninfo: Fix errors while resolving /././ path components
  * geninfo: preserve-paths makes gcov to fail for long pathnames
  * geninfo: Fix "Can't use an undefined value" error
  * geninfo: Ignore artificial functions during --initial
  * geninfo: Fix data collection for files containing templates
  * genhtml: Unconditionally include anchor for each named line
  * genhtml: Use gmtime for SOURCE_DATE_EPOCH conversion
  * genhtml: honor the SOURCE_DATE_EPOCH variable
  * Tolerate CDPATH being set
  * CONTRIBUTING: Clarify patch format requirements
  * geninfo: Fix accounting of basic blocks in exceptional paths
  * lcov: Fix branch coverage summary
- Depend newly on perl-PerlIO-gzip
* Thu Mar  7 2019 vmiklos@collabora.com
- Update to version 1.14:
  + GCC 8 support
  + Options to filter out source files during data collection based
    on regular expressions
  + Option to show number of missed lines, functions and branches
  + Configuration file option for --demangle-cpp
  + Unconditional HTML anchors in source view
  + SOURCE_DATA_EPOCH support for reproducible builds
  + Multiple bug fixes and performance improvements
* Thu Mar 15 2018 mliska@suse.cz
- Port the package to git server and bump to current trunk in order
  to add support for GCC 8.
- Remove lcov-1.13-except-unreach.patch.
* Thu Dec 22 2016 vmiklos@collabora.co.uk
- Update to version 1.13:
  + Contains bug fixes for a number of issues in various areas of LCOV.
  + Detailed list of changes included in this release:
    http://ltp.sourceforge.net/coverage/lcov/changes.php
- Rename lcov-1.12-except-unreach.patch to lcov-1.13-except-unreach.patch
* Fri Oct  9 2015 vmiklos@collabora.co.uk
- Update to version 1.12:
  + Configurable coverage rate precision
  + Configurable exclusion markers
  + Improved --to-package and --from-package handling
  + Improved --demangle-cpp handling
  + Multiple prefix directories
  + Multiple bug fixes and stability improvements
- Adapt lcov-1.11-except-unreach.patch to upstream changes ->
  lcov-1.12-except-unreach.patch
* Tue May  5 2015 mpluskal@suse.com
- Use url for source
- Cleanup spec file with spec-cleaner
* Sun Jun  1 2014 vmiklos@collabora.co.uk
- Update to version 1.11:
  + Improved support for GCC 4.7
  + Improved performance for specific functions
  + Compatibility support for LLVM's gcov
  + Multiple bug fixes and documentation improvements
- Adapt lcov-1.10-except-unreach.patch to upstream changes
  >  lcov-1.11-except-unreach.patch
* Mon Jan 14 2013 vmiklos@suse.cz
- Update to version 1.10
  + drop lcov-1.9-gcc-compat-4.7.patch, already in upstream
  + carry over lcov-1.9-except-unreach.patch, fixed in post-1.10 CVS
* Sun Jan 13 2013 vmiklos@suse.cz
- add lcov-1.9-except-unreach.patch and lcov-1.9-gcc-compat-4.7.patch to make
  lcov work with gcc-4.7
* Mon Jan 10 2011 poletti.marco@gmail.com
- Update to version 1.9
  + geninfo now prints debugging messages to stderr instead of
    stdout.
  + Some fixes.
  + Added a --list-full-path option for lcov.
  + Added lcov_list_width and lcov_list_truncate_max directives to
    the lcov configuration file to allow for list output
    customization.
  + Improved lcov's list output.
* Sun Feb  7 2010 poletti.marco@gmail.com
- Update to version 1.8
  + Added support for branch coverage measurements
  + Bug fixes
  + genhtml: Added --demangle-cpp option, improved color legend
  + genhtml: Improved coverage rate limits
  + geninfo: Added --derive-func-data and --debug options
  + geninfo: Added support for exclusion markers to exclude source lines
  + lcov: Added support for the linux-2.6.31 upstream gcov kernel support
  + lcov: Added --from-package, --to-package and --derive-func-data options
  + lcov: Added overall coverage result output for more operations
* Thu Sep 24 2009 poletti.marco@gmail.com
- initial package of lcov (version 1.7)
